==> kadu_0.6.5.1.orig.tar.gz: kadu/modules/history/translations/history_fr.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>History</source>
        <translation type="unfinished">Historique</translation>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save messages in history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Status changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show status changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show status changes in history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save status changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save status changes in history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Citation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Message citation in chat window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Don&apos;t cite messages older than</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View history</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryDialog</name>
    <message>
        <source>History</source>
        <translation>Historique</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Trouves</translation>
    </message>
    <message>
        <source>Find &amp;next</source>
        <translation>Trouves &amp;suivant</translation>
    </message>
    <message>
        <source>Find &amp;previous</source>
        <translation>Trouves &amp;celui d&apos;avant</translation>
    </message>
    <message>
        <source>Online</source>
        <translation>Accessible</translation>
    </message>
    <message>
        <source>Busy</source>
        <translation>Je reviens bientôt</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation>Caché</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Non disponible</translation>
    </message>
    <message>
        <source>Uins</source>
        <translation>Numéro GG</translation>
    </message>
    <message>
        <source>Show status changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryManager</name>
    <message>
        <source>Clear history?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryModule</name>
    <message>
        <source>Show history</source>
        <translation>Montre historique</translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation type="unfinished">Efface historique</translation>
    </message>
    <message>
        <source>%1 day(s) %2 hour(s)</source>
        <translation type="unfinished">jours: %1 heures: %2</translation>
    </message>
    <message>
        <source>The following users were deleted:
%0Do you want to remove history as well?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistorySearchDialog</name>
    <message>
        <source>Search history</source>
        <translation>Cherche dans l&apos;historique</translation>
    </message>
    <message>
        <source>&amp;From:</source>
        <translation>&amp;de:</translation>
    </message>
    <message>
        <source>day</source>
        <translation>jour</translation>
    </message>
    <message>
        <source>month</source>
        <translation>mois</translation>
    </message>
    <message>
        <source>year</source>
        <translation>année</translation>
    </message>
    <message>
        <source>hour</source>
        <translation>heure</translation>
    </message>
    <message>
        <source>minute</source>
        <translation>min.</translation>
    </message>
    <message>
        <source>Find Criteria</source>
        <translation>Critères de recherche</translation>
    </message>
    <message>
        <source>&amp;Pattern</source>
        <translation>&amp;Exemple</translation>
    </message>
    <message>
        <source>&amp;Status</source>
        <translation>&amp;Statut</translation>
    </message>
    <message>
        <source>Pattern</source>
        <translation>Exemple</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Statut</translation>
    </message>
    <message>
        <source>&amp;Reverse find</source>
        <translation>&amp;Recherche en arrière</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Trouves</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Effaces</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annule</translation>
    </message>
</context>
</TS>

==> kadu_0.6.5.3.orig.tar.gz: kadu/modules/history/translations/history_fr.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>History</source>
        <translation type="unfinished">Historique</translation>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save messages in history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Status changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show status changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show status changes in history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save status changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save status changes in history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Citation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Message citation in chat window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Don&apos;t cite messages older than</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View history</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryDialog</name>
    <message>
        <source>History</source>
        <translation>Historique</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Trouves</translation>
    </message>
    <message>
        <source>Find &amp;next</source>
        <translation>Trouves &amp;suivant</translation>
    </message>
    <message>
        <source>Find &amp;previous</source>
        <translation>Trouves &amp;celui d&apos;avant</translation>
    </message>
    <message>
        <source>Online</source>
        <translation>Accessible</translation>
    </message>
    <message>
        <source>Busy</source>
        <translation>Je reviens bientôt</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation>Caché</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Non disponible</translation>
    </message>
    <message>
        <source>Uins</source>
        <translation>Numéro GG</translation>
    </message>
    <message>
        <source>Show status changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation>Efface historique</translation>
    </message>
    <message>
        <source>Rebuild index</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryManager</name>
    <message>
        <source>Clear history?</source>
        <translation type="unfinished">Efface historique?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error opening history file </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error opening sms history file </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error opening new history file </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error opening new sms history file </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryModule</name>
    <message>
        <source>Show history</source>
        <translation>Montre historique</translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation type="unfinished">Efface historique</translation>
    </message>
    <message>
        <source>%1 day(s) %2 hour(s)</source>
        <translation type="unfinished">jours: %1 heures: %2</translation>
    </message>
    <message>
        <source>The following users were deleted:
%0Do you want to remove history as well?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistorySearchDialog</name>
    <message>
        <source>Search history</source>
        <translation>Cherche dans l&apos;historique</translation>
    </message>
    <message>
        <source>&amp;From:</source>
        <translation>&amp;de:</translation>
    </message>
    <message>
        <source>day</source>
        <translation>jour</translation>
    </message>
    <message>
        <source>month</source>
        <translation>mois</translation>
    </message>
    <message>
        <source>year</source>
        <translation>année</translation>
    </message>
    <message>
        <source>hour</source>
        <translation>heure</translation>
    </message>
    <message>
        <source>minute</source>
        <translation>min.</translation>
    </message>
    <message>
        <source>Find Criteria</source>
        <translation>Critères de recherche</translation>
    </message>
    <message>
        <source>&amp;Pattern</source>
        <translation>&amp;Exemple</translation>
    </message>
    <message>
        <source>&amp;Status</source>
        <translation>&amp;Statut</translation>
    </message>
    <message>
        <source>Pattern</source>
        <translation>Exemple</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Statut</translation>
    </message>
    <message>
        <source>&amp;Reverse find</source>
        <translation>&amp;Recherche en arrière</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Trouves</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Effaces</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annule</translation>
    </message>
</context>
</TS>
